@@ -92,8 +92,8 @@ new LambdaToSns(this, "test-lambda-sns-stack", new LambdaToSnsProps.Builder()
 |existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for Amazon SQS. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
 |vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
 |deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
-|topicArnEnvironmentVariableName?|`string`|Optional Name for the SNS topic arn environment variable set for the Lambda function.|
-|topicNameEnvironmentVariableName?|`string`|Optional Name for the SNS topic name environment variable set for the Lambda function.|
+|topicArnEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the arn of the topic. Default: SNS_TOPIC_ARN |
+|topicNameEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the name of the topic. Default: SNS_TOPIC_NAME |
 
 ## Pattern Properties
 
@@ -131,7 +131,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -183,8 +183,8 @@ class LambdaToSns(
         :param existing_topic_obj: Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. Default: - Default props are used
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
-        :param topic_arn_environment_variable_name: Optional Name for the SNS topic arn environment variable set for the Lambda function. Default: - None
-        :param topic_name_environment_variable_name: Optional Name for the SNS topic name environment variable set for the Lambda function. Default: - None
+        :param topic_arn_environment_variable_name: Optional Name for the Lambda function environment variable set to the arn of the Topic. Default: - SNS_TOPIC_ARN
+        :param topic_name_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the Topic. Default: - SNS_TOPIC_NAME
         :param topic_props: Optional user provided properties to override the default properties for the SNS topic. Default: - Default properties are used.
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
@@ -257,8 +257,8 @@ class LambdaToSnsProps:
         :param existing_topic_obj: Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. Default: - Default props are used
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
-        :param topic_arn_environment_variable_name: Optional Name for the SNS topic arn environment variable set for the Lambda function. Default: - None
-        :param topic_name_environment_variable_name: Optional Name for the SNS topic name environment variable set for the Lambda function. Default: - None
+        :param topic_arn_environment_variable_name: Optional Name for the Lambda function environment variable set to the arn of the Topic. Default: - SNS_TOPIC_ARN
+        :param topic_name_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the Topic. Default: - SNS_TOPIC_NAME
         :param topic_props: Optional user provided properties to override the default properties for the SNS topic. Default: - Default properties are used.
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
@@ -336,18 +336,18 @@ class LambdaToSnsProps:
 
     @builtins.property
     def topic_arn_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the SNS topic arn environment variable set for the Lambda function.
+        '''Optional Name for the Lambda function environment variable set to the arn of the Topic.
 
-        :default: - None
+        :default: - SNS_TOPIC_ARN
         '''
         result = self._values.get("topic_arn_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def topic_name_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the SNS topic name environment variable set for the Lambda function.
+        '''Optional Name for the Lambda function environment variable set to the name of the Topic.
 
-        :default: - None
+        :default: - SNS_TOPIC_NAME
         '''
         result = self._values.get("topic_name_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
